@@ -1,9 +1,11 @@
+""" A dummy deploy step, which produces `mpyl.steps.models.ArtifactType.NONE`."""
+
 from logging import Logger
 
 from ..step import Step
 
 from ..models import Meta, Input, Output, ArtifactType
-from ...stage import Stage
+from ...project import Stage
 
 
 class DeployEcho(Step):
