@@ -1,3 +1,5 @@
+""" Step that deploys the docker image produced in the build stage to Kubernetes, using HELM. """
+
 from logging import Logger
 
 from kubernetes import config, client
@@ -6,7 +8,7 @@ from .k8s import helm
 from .k8s.rancher import rancher_namespace_metadata, cluster_config
 from ..models import Meta, Input, Output, ArtifactType
 from ..step import Step
-from ...stage import Stage
+from ...project import Stage
 
 
 class DeployKubernetes(Step):
@@ -24,7 +26,7 @@ class DeployKubernetes(Step):
         if not step_input.required_artifact:
             return Output(success=False, message=f"Step requires artifact of type {self.required_artifact}")
 
-        properties = step_input.build_properties
+        properties = step_input.run_properties
         context = cluster_config(properties.target).context
         config.load_kube_config(context=context)
         self._logger.info(f"Deploying target {properties.target} and k8s context {context}")
